@@ -9,6 +9,7 @@
 #' @param pal Palette of colors available or the number of the position
 #' @param n integer; number of colors
 #' @param colorRampPalette Logical; to be used in sf and mapview.
+#' @param rev Logical; to internally revert order of rgb color vectors.
 #'
 #'
 #' @return A colour palette function.
@@ -19,6 +20,7 @@
 #' image(matrix(1:100), col = cpt(pal = "mpl_inferno"))
 #' find_cpt("temperature")
 #' image(matrix(1:100), col = cpt("idv_temperature"))
+#' image(matrix(1:100), col = cpt("idv_temperature", rev = TRUE))
 #' \dontrun{
 #' # Do not run
 #' library(ggplot2)
@@ -30,13 +32,14 @@
 #'  scale_fill_gradientn(colours = cpt(n = 100))
 #' }
 #' }
-cpt <- function(pal = "mpl_inferno", n = 100, colorRampPalette = FALSE){
+cpt <- function(pal = "mpl_inferno", n = 100, colorRampPalette = FALSE, rev = FALSE){
   m <- sysdata[[pal]]
+  if(rev) m <- m[nrow(m):1, ]
   col <-  rgb(red = m$r, green = m$g, blue = m$b,
               maxColorValue = max(c(max(m$r, na.rm = T),
                                     max(m$g, na.rm = T),
                                     max(m$b, na.rm = T)))
-              )
+  )
   if(colorRampPalette == FALSE){
     return(grDevices::colorRampPalette(col)(n))
   } else{
